@@ -36,14 +36,18 @@
 #define CACHE_SIZE		"cache_size"
 #define PLUGIN_CACHE_SIZE		"plugin_cache_size"
 #define OSDLEVEL		"osdlevel"
-#define PPLEVEL		"pplevel"
+#define PPLEVEL			"pplevel"
 #define SOFTVOL			"softvol"
+#define VOLUME_GAIN		"volume_gain"
+#define REMEMBER_SOFTVOL	"remember_softvol"
+#define VOLUME_SOFTVOL	"volume_softvol"
 #define VERBOSE			"verbose"
 #define VERTICAL		"vertical"
 #define FORCECACHE		"forcecache"
 #define LAST_DIR		"last_dir"
 #define SHOWPLAYLIST	"showplaylist"
-#define SHOWDETAILS	"showdetails"
+#define SHOWDETAILS		"showdetails"
+#define SHOW_CONTROLS   "show_controls"
 #define DISABLEASS          "disableass"
 #define DISABLEEMBEDDEDFONTS    "disableembeddedfonts"
 #define DISABLEDEINTERLACE	"disable_deinterlace"
@@ -71,9 +75,12 @@
 #define DISABLE_COVER_ART_FETCH "disable_cover_art_fetch"
 #define FULLSCREEN	"fullscreen"
 
+
 #define MPLAYER_BIN		"mplayer_bin"
 #define EXTRAOPTS		"extraopts"
 #define USE_PULSE_FLAT_VOLUME "use_pulse_flat_volume"
+#define USE_XSCRNSAVER "use_xscrnsaver"
+#define MPLAYER_DVD_DEVICE "mplayer_dvd_device"
 
 #define DISABLE_QT		"disable_qt"
 #define DISABLE_REAL	"disable_real"
@@ -87,6 +94,7 @@
 #define WINDOW_Y		"window_y"
 #define WINDOW_HEIGHT	"window_height"
 #define WINDOW_WIDTH	"window_width"
+#define PANEL_POSITION	    "panel_position"
 
 #define RESIZE_ON_NEW_MEDIA "resize_on_new_media"
 #define KEEP_ON_TOP		"keep_on_top"
@@ -266,6 +274,11 @@ typedef struct _Export {
     gint16 payload[7][512];
 } Export;
 
+typedef struct _ButtonDef {
+    gchar *uri;
+    gchar *hrefid;
+} ButtonDef;
+
 #define METER_BARS 		44
 gint buckets[METER_BARS];
 gint max_buckets[METER_BARS];
@@ -295,6 +308,9 @@ gint window_x;
 gint window_y;
 gint control_id;
 gboolean softvol;
+gboolean remember_softvol;
+gint volume_softvol;
+gint volume_gain;
 gint verbose;
 gint reallyverbose;
 gint autostart;
@@ -357,6 +373,7 @@ gboolean subtitle_shadow;
 gint subtitle_margin;
 gboolean quit_on_complete;
 gchar *mplayer_bin;
+gchar *mplayer_dvd_device;
 gchar *extraopts;
 gboolean resize_on_new_media;
 gboolean use_pulse_flat_volume;
@@ -373,13 +390,16 @@ gboolean disable_cover_art_fetch;
 gboolean updating_recent;
 gboolean large_buttons;
 gint button_size;
+gboolean use_xscrnsaver;
 
 gboolean remember_loc;
 gboolean use_remember_loc;
+gboolean save_loc;
 gint loc_window_x;
 gint loc_window_y;
 gint loc_window_height;
 gint loc_window_width;
+gint loc_panel_position;
 gboolean keep_on_top;
 
 gboolean cancel_folder_load;
@@ -465,11 +485,13 @@ gboolean set_update_gui(void *data);
 gboolean set_subtitle_visibility(void *data);
 gboolean set_item_add_info(void *data);
 gboolean set_metadata(gpointer data);
+gboolean set_pane_position(void *data);
 
 void remove_langs(GtkWidget * item, gpointer data);
 gboolean set_new_lang_menu(gpointer data);
 gboolean set_new_audio_menu(gpointer data);
 gboolean make_panel_and_mouse_invisible(gpointer data);
+gboolean idle_make_button(gpointer data);
 void make_button(gchar * src, gchar * href);
 void dbus_open_by_hrefid(gchar * hrefid);
 void dbus_open_next();
@@ -486,6 +508,7 @@ void dbus_disable_screensaver();
 void menuitem_edit_random_callback(GtkMenuItem * menuitem, void *data);
 
 gboolean update_audio_meter(gpointer data);
+gboolean update_volume(gpointer data);
 
 void mplayer_shutdown();
 gpointer launch_player(gpointer data);
