@@ -68,6 +68,7 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
     gchar *xml_string;
     gint source_id;
     gint bitrate;
+    ButtonDef *b;
 
     message_type = dbus_message_get_type(message);
     sender = dbus_message_get_sender(message);
@@ -98,14 +99,21 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
             // printf("Path matched %s\n", dbus_message_get_path(message));
             if (message_type == DBUS_MESSAGE_TYPE_SIGNAL) {
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "Open") == 0) {
-                    g_idle_add(set_kill_mplayer,NULL);
+                    g_idle_add(set_kill_mplayer, NULL);
                     dbus_error_init(&error);
                     if (dbus_message_get_args
                         (message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
                         if (strlen(s) > 0) {
-                            if (strcmp(rpconsole, "NONE") == 0 || control_instance == FALSE) {
+                            if (verbose)
+                                printf("opening %s\n", s);
+                            if ((strcmp(rpconsole, "NONE") == 0 || control_instance == FALSE)
+                                && s != NULL) {
                                 g_idle_add(clear_playlist_and_play, g_strdup(s));
                             }
+                        } else {
+                            if (verbose) {
+                                printf("Open requested, but value is blank\n");
+                            }
                         }
 
                     } else {
@@ -115,12 +123,13 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "OpenPlaylist") == 0) {
-                    g_idle_add(set_kill_mplayer,NULL);
+                    g_idle_add(set_kill_mplayer, NULL);
                     dbus_error_init(&error);
                     if (dbus_message_get_args
                         (message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
                         selection = NULL;
-                        g_idle_add(clear_playlist_and_play, g_strdup(s));
+                        if (s != NULL)
+                            g_idle_add(clear_playlist_and_play, g_strdup(s));
 
                     } else {
                         dbus_error_free(&error);
@@ -129,11 +138,14 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "OpenButton") == 0) {
-                    g_idle_add(set_kill_mplayer,NULL);
+                    g_idle_add(set_kill_mplayer, NULL);
                     dbus_error_init(&error);
                     if (dbus_message_get_args(message, &error, DBUS_TYPE_STRING, &s,
                                               DBUS_TYPE_STRING, &hrefid, DBUS_TYPE_INVALID)) {
-                        make_button(s, g_strdup(hrefid));
+                        b = (ButtonDef *) g_new0(ButtonDef, 1);
+                        b->uri = g_strdup(s);
+                        b->hrefid = g_strdup(hrefid);
+                        g_idle_add(idle_make_button, b);
                     } else {
                         dbus_error_free(&error);
                     }
@@ -168,12 +180,12 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "Close") == 0) {
-                    g_idle_add(set_kill_mplayer,NULL);
+                    g_idle_add(set_kill_mplayer, NULL);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "Quit") == 0) {
-                    g_idle_add(set_kill_mplayer,NULL);
+                    g_idle_add(set_kill_mplayer, NULL);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
 
@@ -408,6 +420,7 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                         g_idle_add(set_progress_value, idledata);
                         if (idledata->cachepercent > 0.99 && idledata->retry_on_full_cache) {
                             if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter)) {
+                                //printf("retrying on full cache\n");
                                 play_iter(&iter, 0);
                             }
                         }
@@ -497,7 +510,7 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                     if (dbus_message_get_args
                         (message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
                         g_strlcpy(idledata->url, s, 1024);
-                        show_copyurl(idledata);
+                        g_idle_add(show_copyurl, idledata);
                     } else {
                         dbus_error_free(&error);
                     }
@@ -524,6 +537,7 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                     if (dbus_message_get_args
                         (message, &error, DBUS_TYPE_INT32, &window_x, DBUS_TYPE_INT32, &window_y,
                          DBUS_TYPE_INVALID)) {
+                        if (window_x > 0 && window_y > 0);
                         g_idle_add(resize_window, idledata);
                     } else {
                         dbus_error_free(&error);
@@ -1092,7 +1106,7 @@ gboolean dbus_hookup(gint windowid, gint controlid)
                 if (playlistname != NULL && local_rnp)
                     dbus_set_playlist_name(playlistname);
             }
-            exit(1);
+            exit(EXIT_SUCCESS);
         }
     }
     screensaver_disabled = FALSE;
@@ -1117,22 +1131,32 @@ void dbus_enable_screensaver()
 #endif
 
     if (connection != NULL && screensaver_disabled) {
-#ifdef SM_INHIBIT
-        message =
-            dbus_message_new_method_call("org.gnome.SessionManager", "/org/gnome/SessionManager",
-                                         "org.gnome.SessionManager", "UnInhibit");
-        dbus_message_append_args(message, DBUS_TYPE_INT32, &sm_cookie, DBUS_TYPE_INVALID);
-        dbus_connection_send(connection, message, NULL);
-        dbus_message_unref(message);
+
+        if (use_xscrnsaver) {
+#ifdef XSCRNSAVER_ENABLED
+            XScreenSaverSuspend(GDK_WINDOW_XDISPLAY(window->window), FALSE);
 #endif
-#ifdef SS_INHIBIT
-        message =
-            dbus_message_new_method_call("org.gnome.ScreenSaver", "/org/gnome/ScreenSaver",
-                                         "org.gnome.ScreenSaver", "UnInhibit");
-        dbus_message_append_args(message, DBUS_TYPE_INT32, &ss_cookie, DBUS_TYPE_INVALID);
-        dbus_connection_send(connection, message, NULL);
-        dbus_message_unref(message);
+
+        } else {
+#if SM_INHIBIT
+            message =
+                dbus_message_new_method_call("org.gnome.SessionManager",
+                                             "/org/gnome/SessionManager",
+                                             "org.gnome.SessionManager", "UnInhibit");
+            dbus_message_append_args(message, DBUS_TYPE_INT32, &sm_cookie, DBUS_TYPE_INVALID);
+            dbus_connection_send(connection, message, NULL);
+            dbus_message_unref(message);
 #endif
+#if SS_INHIBIT
+            message =
+                dbus_message_new_method_call("org.gnome.ScreenSaver", "/org/gnome/ScreenSaver",
+                                             "org.gnome.ScreenSaver", "UnInhibit");
+            dbus_message_append_args(message, DBUS_TYPE_INT32, &ss_cookie, DBUS_TYPE_INVALID);
+            dbus_connection_send(connection, message, NULL);
+            dbus_message_unref(message);
+#endif
+        }
+
         screensaver_disabled = FALSE;
     }
 }
@@ -1148,49 +1172,61 @@ void dbus_disable_screensaver()
     gint flags;
 #endif
 
-    if (connection != NULL) {
+    if (connection != NULL && screensaver_disabled == FALSE) {
+        if (use_xscrnsaver) {
 
-#ifdef SS_INHIBIT
-        dbus_error_init(&error);
-        message =
-            dbus_message_new_method_call("org.gnome.ScreenSaver", "/org/gnome/ScreenSaver",
-                                         "org.gnome.ScreenSaver", "Inhibit");
-        app = g_strdup_printf("gnome-mplayer");
-        reason = g_strdup_printf("playback");
-        dbus_message_append_args(message, DBUS_TYPE_STRING, &app, DBUS_TYPE_STRING, &reason,
-                                 DBUS_TYPE_INVALID);
-        reply_message = dbus_connection_send_with_reply_and_block(connection, message, 200, &error);
-
-        if (reply_message) {
-            dbus_message_get_args(reply_message, &error, DBUS_TYPE_INT32, &ss_cookie, NULL);
-            dbus_message_unref(reply_message);
-        }
-
-        dbus_message_unref(message);
-        dbus_error_free(&error);
+#ifdef XSCRNSAVER_ENABLED
+            XScreenSaverSuspend(GDK_WINDOW_XDISPLAY(window->window), TRUE);
 #endif
 
-#ifdef SM_INHIBIT
-        dbus_error_init(&error);
-        message =
-            dbus_message_new_method_call("org.gnome.SessionManager", "/org/gnome/SessionManager",
-                                         "org.gnome.SessionManager", "Inhibit");
-        app = g_strdup_printf("gnome-mplayer");
-        reason = g_strdup_printf("playback");
-        flags = 8;
-        dbus_message_append_args(message, DBUS_TYPE_STRING, &app, DBUS_TYPE_UINT32,
-                                 &(idledata->windowid), DBUS_TYPE_STRING, &reason, DBUS_TYPE_UINT32,
-                                 &flags, DBUS_TYPE_INVALID);
-        reply_message = dbus_connection_send_with_reply_and_block(connection, message, 200, &error);
+        } else {
 
-        if (reply_message) {
-            dbus_message_get_args(reply_message, &error, DBUS_TYPE_INT32, &sm_cookie, NULL);
-            dbus_message_unref(reply_message);
+#if SS_INHIBIT
+            dbus_error_init(&error);
+            message =
+                dbus_message_new_method_call("org.gnome.ScreenSaver", "/org/gnome/ScreenSaver",
+                                             "org.gnome.ScreenSaver", "Inhibit");
+            app = g_strdup_printf("gnome-mplayer");
+            reason = g_strdup_printf("playback");
+            dbus_message_append_args(message, DBUS_TYPE_STRING, &app, DBUS_TYPE_STRING, &reason,
+                                     DBUS_TYPE_INVALID);
+            reply_message =
+                dbus_connection_send_with_reply_and_block(connection, message, 200, &error);
+
+            if (reply_message) {
+                dbus_message_get_args(reply_message, &error, DBUS_TYPE_INT32, &ss_cookie, NULL);
+                dbus_message_unref(reply_message);
+            }
+
+            dbus_message_unref(message);
+            dbus_error_free(&error);
+#endif
+
+#if SM_INHIBIT
+            dbus_error_init(&error);
+            message =
+                dbus_message_new_method_call("org.gnome.SessionManager",
+                                             "/org/gnome/SessionManager",
+                                             "org.gnome.SessionManager", "Inhibit");
+            app = g_strdup_printf("gnome-mplayer");
+            reason = g_strdup_printf("playback");
+            flags = 8;
+            dbus_message_append_args(message, DBUS_TYPE_STRING, &app, DBUS_TYPE_UINT32,
+                                     &(idledata->windowid), DBUS_TYPE_STRING, &reason,
+                                     DBUS_TYPE_UINT32, &flags, DBUS_TYPE_INVALID);
+            reply_message =
+                dbus_connection_send_with_reply_and_block(connection, message, 200, &error);
+
+            if (reply_message) {
+                dbus_message_get_args(reply_message, &error, DBUS_TYPE_INT32, &sm_cookie, NULL);
+                dbus_message_unref(reply_message);
+            }
+
+            dbus_message_unref(message);
+            dbus_error_free(&error);
+#endif
         }
 
-        dbus_message_unref(message);
-        dbus_error_free(&error);
-#endif
         screensaver_disabled = TRUE;
     }
 }
