@@ -49,6 +49,7 @@ GtkWidget *menubar;
 GtkMenuItem *menuitem_file;
 GtkMenu *menu_file;
 GtkMenuItem *menuitem_file_open;
+GtkMenuItem *menuitem_file_open_folder;
 GtkMenuItem *menuitem_file_open_location;
 GtkMenuItem *menuitem_file_disc;
 GtkMenu *menu_file_disc;
@@ -247,12 +248,15 @@ GtkWidget *config_bring_to_front;
 GtkWidget *config_resize_on_new_media;
 GtkWidget *config_pause_on_click;
 GtkWidget *config_softvol;
+GtkWidget *config_remember_softvol;
+GtkWidget *config_volume_gain;
 GtkWidget *config_forcecache;
 GtkWidget *config_verbose;
 GtkWidget *config_show_notification;
-GtkWidget *config_thumb_position;
+GtkWidget *config_use_xscrnsaver;
 GtkWidget *config_use_mediakeys;
 GtkWidget *config_use_defaultpl;
+GtkWidget *config_disable_animation;
 
 GtkWidget *config_alang;
 GtkWidget *config_slang;
@@ -277,6 +281,7 @@ GtkWidget *config_midi;
 GtkWidget *config_noembed;
 
 GtkWidget *config_mplayer_bin;
+GtkWidget *config_mplayer_dvd_device;
 GtkWidget *config_extraopts;
 GtkWidget *config_remember_loc;
 GtkWidget *config_keep_on_top;
@@ -332,6 +337,7 @@ void menuitem_view_decrease_subtitle_delay_callback(GtkMenuItem * menuitem, void
 void menuitem_view_increase_subtitle_delay_callback(GtkMenuItem * menuitem, void *data);
 void clear_playlist(GtkWidget * widget, void *data);
 void create_playlist_widget();
+void add_folder_to_playlist(GtkWidget * widget, void *data);
 gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
                                 gint x, gint y, GtkSelectionData * selection_data,
                                 guint info, guint t, gpointer data);
@@ -340,6 +346,7 @@ void destroy_folder_progress_window();
 void update_status_icon();
 void setup_accelerators();
 void update_details_table();
+gboolean set_software_volume(int *data);
 
 gint get_height();
 gint get_width();
