@@ -117,6 +117,7 @@ static MetaData *get_metadata(gchar * filename)
     av[ac++] = g_strdup_printf("-noidx");
     av[ac++] = g_strdup_printf("-identify");
     av[ac++] = g_strdup_printf("-nocache");
+    av[ac++] = g_strdup_printf("-noidle");
 
     av[ac++] = g_strdup_printf("%s", filename);
     av[ac] = NULL;
@@ -137,6 +138,8 @@ static MetaData *get_metadata(gchar * filename)
             g_free(out);
         if (err != NULL)
             g_free(err);
+        if (ret != NULL)
+            g_free(ret);
         return NULL;
     }
     output = g_strsplit(out, "\n", 0);
@@ -151,7 +154,7 @@ static MetaData *get_metadata(gchar * filename)
             ret->length_value = f;
         }
 
-        if (g_strncasecmp(output[ac], "ID_CLIP_INFO_NAME", strlen("ID_CLIP_INFO_NAME")) == 0) {
+        if (g_ascii_strncasecmp(output[ac], "ID_CLIP_INFO_NAME", strlen("ID_CLIP_INFO_NAME")) == 0) {
             if (strstr(lower, "=title") != NULL || strstr(lower, "=name") != NULL) {
                 ptr = strstr(output[ac + 1], "=") + 1;
                 if (ptr)
