@@ -52,11 +52,14 @@
 #endif
 
 gint get_bitrate(gchar * name);
+MetaData *get_metadata(gchar * uri);
+MetaData *get_basic_metadata(gchar * uri);
 void strip_unicode(gchar * data, gsize len);
-gint play_iter(GtkTreeIter * playiter);
+gint play_iter(GtkTreeIter * playiter, gint restart_second);
 gint detect_playlist(gchar * filename);
 gchar *metadata_to_utf8(gchar * string);
 gint parse_playlist(gchar * uri);
+gint parse_asx(gchar * uri);
 gint parse_basic(gchar * filename);
 gint parse_ram(gchar * filename);
 gint parse_cdda(gchar * filename);
@@ -70,10 +73,13 @@ gboolean send_command(gchar * command, gboolean retain_pause);
 gboolean streaming_media(gchar * filename);
 gboolean device_name(gchar * filename);
 gboolean add_item_to_playlist(const gchar * uri, gint playlist);
+gboolean first_item_in_playlist(GtkTreeIter * iter);
+gboolean prev_item_in_playlist(GtkTreeIter * iter);
 gboolean next_item_in_playlist(GtkTreeIter * iter);
-void copy_playlist(GtkListStore * source, GtkListStore * dest);
 void randomize_playlist(GtkListStore * store);
-gdouble get_alsa_volume();
+void reset_playlist_order(GtkListStore * store);
+gdouble get_alsa_volume(gboolean show_details);
+gboolean set_alsa_volume(gboolean show_details, gint volume);
 gchar *seconds_to_string(gfloat seconds);
 
 gchar *get_localfile_from_uri(gchar * uri);
@@ -93,4 +99,7 @@ gboolean detect_volume_option();
 gboolean map_af_export_file(gpointer data);
 gboolean unmap_af_export_file(gpointer data);
 
+gboolean add_to_playlist_and_play(gpointer data);
+gboolean clear_playlist_and_play(gpointer data);
+
 #endif                          // _SUPPORT_H
