@@ -107,6 +107,8 @@ gboolean thread_complete(GIOChannel * source, GIOCondition condition, gpointer d
         printf("thread complete\n");
     g_idle_add(set_stop, idledata);
     state = QUIT;
+    lastguistate = STOPPED;
+    g_idle_add(set_gui_state, NULL);
     g_source_remove(watch_in_id);
     g_source_remove(watch_err_id);
     g_cond_signal(mplayer_complete_cond);
@@ -137,7 +139,8 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
         if (verbose)
             printf("shutting down threadquery for %s since threaddata->done is TRUE\n",
                    threaddata->filename);
-        g_free(threaddata);
+        if (threaddata != NULL)
+            g_free(threaddata);
         threaddata = NULL;
         return FALSE;
     }
@@ -233,9 +236,15 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
         playback_error = ERROR_RETRY_WITH_PLAYLIST;
     }
 
+    if (strstr(mplayer_output->str, "playlist support will not be used") != NULL) {
+        dontplaynext = TRUE;
+        playback_error = ERROR_RETRY_WITH_PLAYLIST;
+    }
+
     if (strstr(mplayer_output->str, "MOV: missing header (moov/cmov) chunk") != NULL) {
         idledata->retry_on_full_cache = TRUE;
         g_strlcpy(idledata->progress_text, _("Delaying start until cache is full"), 1024);
+        //printf("delaying start\n");
         g_idle_add(set_progress_text, idledata);
     }
 
@@ -247,6 +256,10 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
         //g_idle_add(set_rew, idledata);
     }
 
+    if (strstr(mplayer_output->str, "LD_PRELOAD") != NULL) {
+        // not a real error
+    }
+
     if (error_msg != NULL) {
         dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
                                         GTK_BUTTONS_CLOSE, "%s", error_msg);
@@ -267,9 +280,10 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
 
     GString *mplayer_output;
     GIOStatus status;
-    gchar *buf, *message = NULL;
+    gchar *buf, *message = NULL, *icy = NULL;
     gchar *cmd;
-    gint pos, volume, i;
+    gint pos, i;
+    gfloat vol;
     gfloat percent;
     GError *error = NULL;
     gchar *error_msg = NULL;
@@ -277,6 +291,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
     gdouble old_pos;
     LangMenu *menu;
     ThreadData *threaddata = (ThreadData *) data;
+    MetaData *metadata;
 
     if (source == NULL) {
         g_source_remove(watch_err_id);
@@ -296,7 +311,8 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         if (verbose)
             printf("shutting down threadquery for %s since threaddata->done is TRUE\n",
                    threaddata->filename);
-        g_free(threaddata);
+        if (threaddata != NULL)
+            g_free(threaddata);
         threaddata = NULL;
         return FALSE;
     }
@@ -502,18 +518,18 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         buf = strstr(mplayer_output->str, "ANS_stream_pos");
         sscanf(buf, "ANS_stream_pos=%li", &idledata->byte_pos);
         g_idle_add(set_progress_time, idledata);
+        lastguistate = STOPPED;
+        guistate = PLAYING;
+        g_idle_add(set_gui_state, NULL);
     }
 
     if (strstr(mplayer_output->str, "ANS_volume") != 0) {
         buf = strstr(mplayer_output->str, "ANS_volume");
-        sscanf(buf, "ANS_volume=%i", &volume);
-        if (!idledata->mute) {
-            if (use_pulse_flat_volume && !softvol) {
-                // Need to track what the master volume is, gui is updated in make mouse invisible
-                idledata->mplayer_volume = volume;
-                idledata->mute = (volume > 0);
-            }
-        }
+        sscanf(buf, "ANS_volume=%f", &vol);
+        // Need to track what the master volume is, gui is updated in make mouse invisible
+        idledata->mplayer_volume = vol;
+        idledata->mute = !((gint) vol > 0);
+        g_idle_add(update_volume, idledata);
     }
 
     if (strstr(mplayer_output->str, "ANS_chapters") != 0) {
@@ -766,6 +782,15 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
             g_strlcpy(idledata->media_info, message, 1024);
             g_free(message);
             message = g_markup_printf_escaped("\n\t<b>%s</b>\n", buf + 1);
+            icy = g_strdup(buf + 1);
+            if ((buf = strstr(icy, " - ")) != NULL) {
+                metadata = (MetaData *) g_new0(MetaData, 1);
+                metadata->title = g_strdup(buf + 3);
+                buf[0] = '\0';
+                metadata->artist = g_strdup(icy);
+                g_thread_create(get_cover_art, metadata, FALSE, NULL);
+            }
+            g_free(icy);
             g_strlcpy(idledata->media_notification, message, 1024);
             g_free(message);
             message = NULL;
@@ -827,24 +852,19 @@ gboolean thread_query(gpointer data)
         // but don't start polling until meter is visible
         g_idle_add(map_af_export_file, idledata);
     }
-    // track volume control
-    if (use_pulse_flat_volume && !softvol) {
-        volume = (gint) get_alsa_volume(FALSE);
-        idledata->volume = volume;
-        if (!idledata->mute)
-            g_idle_add(set_volume, idledata);
-    }
 
     if (state == PLAYING) {
         // size = write(std_in, "get_percent_pos\n", strlen("get_percent_pos\n"));
         size = write(std_in, "get_time_pos\n", strlen("get_time_pos\n"));
         if (size == -1) {
-            g_idle_add(set_kill_mplayer,NULL);
+            g_idle_add(set_kill_mplayer, NULL);
             return FALSE;
         } else {
 
             //send_command("get_time_pos\n");
+            send_command("get_time_length\n", TRUE);
             send_command("get_property stream_pos\n", TRUE);
+            send_command("get_property volume\n", TRUE);
             if (threaddata->streaming)
                 send_command("get_property metadata\n", TRUE);
             g_idle_add(make_panel_and_mouse_invisible, NULL);
@@ -975,15 +995,23 @@ gpointer launch_player(gpointer data)
     argv[arg++] = g_strdup_printf("-identify");
 
     // this argument seems to cause noise in some videos
-    if (softvol)
-        argv[arg++] = g_strdup_printf("-softvol");
+    if (softvol) {
+        if (volume_gain != 0) {
+            argv[arg++] = g_strdup_printf("-af-add");
+            argv[arg++] = g_strdup_printf("volume=%i", volume_gain);
+        } else {
+            argv[arg++] = g_strdup_printf("-softvol");
+        }
+    }
 
     if (use_volume_option) {
         argv[arg++] = g_strdup_printf("-volume");
-        if (idledata->mute)
-            argv[arg++] = g_strdup_printf("0");
-        else
-            argv[arg++] = g_strdup_printf("%i", (gint) idledata->volume);
+        //if (idledata->mute) {
+        //    argv[arg++] = g_strdup_printf("0");
+        //} else {
+        argv[arg++] = g_strdup_printf("%i", (gint) idledata->volume);
+        idledata->mplayer_volume = idledata->volume;
+        //}
     }
 
     if (mixer != NULL && strlen(mixer) > 0) {
@@ -1009,8 +1037,8 @@ gpointer launch_player(gpointer data)
     argv[arg++] = g_strdup_printf("-noidle");
 
 #if !(SM_INHIBIT || SS_INHIBIT)
-    if (idledata->width > 0 && idledata->height > 0)
-        argv[arg++] = g_strdup_printf("-stop-xscreensaver");
+//    if (idledata->width > 0 && idledata->height > 0)
+//        argv[arg++] = g_strdup_printf("-stop-xscreensaver");
 #endif
 
     argv[arg++] = g_strdup_printf("-osdlevel");
@@ -1019,6 +1047,7 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("-mouse-movements");
         argv[arg++] = g_strdup_printf("-nocache");
     } else {
+        // argv[arg++] = g_strdup_printf("-nograbpointer");
         if (g_ascii_strncasecmp(threaddata->filename, "dvd://", strlen("dvd://")) == 0) {
             // argv[arg++] = g_strdup_printf("-nocache");
         } else {
@@ -1209,6 +1238,11 @@ gpointer launch_player(gpointer data)
     if (idledata->device != NULL) {
         argv[arg++] = g_strdup_printf("-dvd-device");
         argv[arg++] = g_strdup_printf("%s", idledata->device);
+    } else {
+        if (mplayer_dvd_device != NULL) {
+            argv[arg++] = g_strdup_printf("-dvd-device");
+            argv[arg++] = g_strdup_printf("%s", mplayer_dvd_device);
+        }
     }
 
     /* 
@@ -1240,7 +1274,7 @@ gpointer launch_player(gpointer data)
 
     if (g_strrstr(threaddata->filename, "apple.com")) {
         argv[arg++] = g_strdup_printf("-user-agent");
-        argv[arg++] = g_strdup_printf("QuickTime/7.6.2");
+        argv[arg++] = g_strdup_printf("QuickTime/7.6.4");
     }
 
 
@@ -1281,7 +1315,7 @@ gpointer launch_player(gpointer data)
     if (ok) {
         if (verbose)
             printf("Spawn succeeded for filename %s\n", threaddata->filename);
-        state = PAUSED;
+        state = PLAYING;
 
         if (channel_in != NULL) {
             g_io_channel_unref(channel_in);
@@ -1318,7 +1352,9 @@ gpointer launch_player(gpointer data)
 //        watch_err_id = g_io_add_watch(channel_err, G_IO_IN | G_IO_ERR | G_IO_HUP, thread_reader_error, NULL);
 //        watch_in_hup_id = g_io_add_watch(channel_in, G_IO_ERR | G_IO_HUP, thread_complete, NULL);
 
-        g_idle_add(set_play, NULL);
+        //g_idle_add(set_play, NULL);
+        guistate = PLAYING;
+        g_idle_add(set_gui_state, NULL);
 #ifdef GLIB2_14_ENABLED
         g_timeout_add_seconds(1, thread_query, threaddata);
 #else
